Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(452)

Unified Diff: pkg/compiler/lib/src/io/source_information.dart

Issue 1902363002: Derive source information from ResolvedAst. (Closed) Base URL: https://github.com/dart-lang/sdk.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/compiler/lib/src/io/source_information.dart
diff --git a/pkg/compiler/lib/src/io/source_information.dart b/pkg/compiler/lib/src/io/source_information.dart
index 0f6bbace841c906db35d20d054cee16bdb28cf79..cf3872cd0e35f229c23db196461c2f062247b6ad 100644
--- a/pkg/compiler/lib/src/io/source_information.dart
+++ b/pkg/compiler/lib/src/io/source_information.dart
@@ -5,7 +5,7 @@
library dart2js.source_information;
import '../common.dart';
-import '../elements/elements.dart' show AstElement, LocalElement;
+import '../elements/elements.dart' show AstElement, LocalElement, ResolvedAst;
import '../js/js.dart' show JavaScriptNodeSourceInformation;
import '../tree/tree.dart' show Node;
import 'source_file.dart';
@@ -56,8 +56,9 @@ class SourceInformationBuilder {
/// Create a [SourceInformationBuilder] for [element].
SourceInformationBuilder forContext(AstElement element) => this;
- /// Generate [SourceInformation] the declaration of [element].
- SourceInformation buildDeclaration(AstElement element) => null;
+ /// Generate [SourceInformation] the declaration of the element in
+ /// [resolvedAst].
+ SourceInformation buildDeclaration(ResolvedAst resolvedAst) => null;
/// Generate [SourceInformation] for the generic [node].
@deprecated
« no previous file with comments | « pkg/compiler/lib/src/io/position_information.dart ('k') | pkg/compiler/lib/src/io/start_end_information.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698